@@ -16,12 +16,12 @@ class PublishVideo:
             self.audio_download = True
         else:
             self.audio_download = False
-            self.audio = audio
+        self.audio = audio
         if check_if_url(cover):
             self.cover_download = True
         else:
             self.cover_download = False
-            self.cover = cover
+        self.cover = cover
 
     def speed(self, speed):
         self.speed = speed
@@ -59,7 +59,7 @@ class PublishVideo:
             self.audiofile = f'pagman? {self.song}.wav'
             self.folder = f'pagman? {self.song}'
 
-    def make(self, compress_files=False, upload_yt=None, secrets_folder=None, client_secrets=None):
+    def make(self, compress_files=False):
 
         new_folder = False
         self.starting_directory = getcwd()
